pub enum Channel {
    SavedMessages {
        id: String,
        user: String,
    },
    DirectMessage {
        id: String,
        active: bool,
        recipients: Vec<String>,
        last_message_id: Option<String>,
    },
    Group {
        id: String,
        name: String,
        owner: String,
        description: Option<String>,
        recipients: Vec<String>,
        icon: Option<File>,
        last_message_id: Option<String>,
        permissions: Option<i64>,
        nsfw: bool,
    },
    TextChannel {
        id: String,
        server: String,
        name: String,
        description: Option<String>,
        icon: Option<File>,
        last_message_id: Option<String>,
        default_permissions: Option<OverrideField>,
        role_permissions: HashMap<String, OverrideField>,
        nsfw: bool,
    },
    VoiceChannel {
        id: String,
        server: String,
        name: String,
        description: Option<String>,
        icon: Option<File>,
        default_permissions: Option<OverrideField>,
        role_permissions: HashMap<String, OverrideField>,
        nsfw: bool,
    },
}

Variants



SavedMessages

Fields

id: String

Unique Id

user: String

Id of the user this channel belongs to

Personal “Saved Notes” channel which allows users to save messages



DirectMessage

Fields

id: String

Unique Id

active: bool

Whether this direct message channel is currently open on both sides

recipients: Vec<String>

2-tuple of user ids participating in direct message

last_message_id: Option<String>

Id of the last message sent in this channel

Direct message channel between two users



Group

Fields

id: String

Unique Id

name: String

Display name of the channel

owner: String

User id of the owner of the group

description: Option<String>

Channel description

recipients: Vec<String>

Array of user ids participating in channel

icon: Option<File>

Custom icon attachment

last_message_id: Option<String>

Id of the last message sent in this channel

permissions: Option<i64>

Permissions assigned to members of this group (does not apply to the owner of the group)

nsfw: bool

Whether this group is marked as not safe for work

Group channel between 1 or more participants



TextChannel

Fields

id: String

Unique Id

server: String

Id of the server this channel belongs to

name: String

Display name of the channel

description: Option<String>

Channel description

icon: Option<File>

Custom icon attachment

last_message_id: Option<String>

Id of the last message sent in this channel

default_permissions: Option<OverrideField>

Default permissions assigned to users in this channel

role_permissions: HashMap<String, OverrideField>

Permissions assigned based on role to this channel

nsfw: bool

Whether this channel is marked as not safe for work

Text channel belonging to a server



VoiceChannel

Fields

id: String

Unique Id

server: String

Id of the server this channel belongs to

name: String

Display name of the channel

description: Option<String>

Channel description

icon: Option<File>

Custom icon attachment

default_permissions: Option<OverrideField>

Default permissions assigned to users in this channel

role_permissions: HashMap<String, OverrideField>

Permissions assigned based on role to this channel

nsfw: bool

Whether this channel is marked as not safe for work

Voice channel belonging to a server

Implementations

source

impl Channel

source

pub async fn create(&self, db: &Database) -> Result<()>

Create a channel

source

pub async fn add_user_to_group( &mut self, db: &Database, user: &User, by_id: &str ) -> Result<()>

Add user to a group

source

pub fn is_direct_dm(&self) -> bool

Map out whether it is a direct DM

source

pub fn contains_user(&self, user_id: &str) -> bool

Check whether has a user as a recipient

source

pub fn users(&self) -> Result<Vec<String>>

Get list of recipients

source

pub fn id(&self) -> String

Get a reference to this channel’s id

source

pub async fn set_role_permission( &mut self, db: &Database, role_id: &str, permissions: OverrideField ) -> Result<()>

Set role permission on a channel

source

pub async fn update( &mut self, db: &Database, partial: PartialChannel, remove: Vec<FieldsChannel> ) -> Result<()>

Update channel data

source

pub fn remove_field(&mut self, field: &FieldsChannel)

Remove a field from Channel object

source

pub fn remove_fields(&mut self, partial: Vec<FieldsChannel>)

Remove multiple fields from Channel object

source

pub fn apply_options(&mut self, partial: PartialChannel)

Apply partial channel to channel

source

pub async fn remove_user_from_group( &self, db: &Database, user: &User, by_id: Option<&str>, silent: bool ) -> Result<()>

Remove user from a group

source

pub async fn delete(&self, db: &Database) -> Result<()>

Delete a channel