Module rabbit

Module rabbit 

Structs

AckEventPayload
This is not the same as the AckPayload above, as the state for this event is stored in redis to allow for state updates while the event is queued.
AckPayload
DmCallPayload
FRAcceptedPayload
FRReceivedPayload
GenericPayload
InternalDmCallPayload
MassMessageSentPayload
MessageSentPayload
PayloadToService

Enums

PayloadKind