pub struct Account {
pub id: String,
pub email: String,
pub email_normalised: String,
pub password: String,
pub disabled: bool,
pub verification: EmailVerification,
pub password_reset: Option<PasswordReset>,
pub deletion: Option<DeletionInfo>,
pub lockout: Option<Lockout>,
pub mfa: MultiFactorAuthentication,
}Expand description
Account model
Fields
id: StringUnique Id
email: StringUser’s email
email_normalised: StringNormalised email
(see https://github.com/insertish/authifier/#how-does-authifier-work)
password: StringArgon2 hashed password
disabled: boolWhether the account is disabled
verification: EmailVerificationEmail verification status
password_reset: Option<PasswordReset>Password reset information
deletion: Option<DeletionInfo>Account deletion information
lockout: Option<Lockout>Account lockout
mfa: MultiFactorAuthenticationMulti-factor authentication information
Implementations
Sourceimpl Account
impl Account
pub fn apply_options(&mut self, optional_struct: PartialAccount)
Sourceimpl Account
impl Account
Sourcepub async fn new(
db: &Database,
email: String,
plaintext_password: String,
verify_email: bool,
) -> Result<Account>
pub async fn new( db: &Database, email: String, plaintext_password: String, verify_email: bool, ) -> Result<Account>
Create a new account
Sourcepub async fn create_session(
&self,
db: &Database,
name: String,
) -> Result<Session>
pub async fn create_session( &self, db: &Database, name: String, ) -> Result<Session>
Create a new session
Sourcepub async fn start_email_verification(&mut self, db: &Database) -> Result<()>
pub async fn start_email_verification(&mut self, db: &Database) -> Result<()>
Send account verification email
Sourcepub async fn start_email_move(
&mut self,
db: &Database,
new_email: String,
) -> Result<()>
pub async fn start_email_move( &mut self, db: &Database, new_email: String, ) -> Result<()>
Send account verification to new email
Sourcepub async fn start_password_reset(
&mut self,
db: &Database,
existing_account: bool,
) -> Result<()>
pub async fn start_password_reset( &mut self, db: &Database, existing_account: bool, ) -> Result<()>
Send password reset email
Sourcepub async fn start_account_deletion(&mut self, db: &Database) -> Result<()>
pub async fn start_account_deletion(&mut self, db: &Database) -> Result<()>
Begin account deletion process by sending confirmation email
If email verification is not on, the account will be marked for deletion instantly
Sourcepub fn verify_password(&self, plaintext_password: &str) -> Result<()>
pub fn verify_password(&self, plaintext_password: &str) -> Result<()>
Verify a user’s password is correct
Sourcepub async fn consume_mfa_response(
&mut self,
db: &Database,
response: MFAResponse,
ticket: Option<MFATicket>,
) -> Result<()>
pub async fn consume_mfa_response( &mut self, db: &Database, response: MFAResponse, ticket: Option<MFATicket>, ) -> Result<()>
Validate an MFA response
Sourcepub async fn delete_all_sessions(
&self,
db: &Database,
exclude_session_id: Option<String>,
) -> Result<()>
pub async fn delete_all_sessions( &self, db: &Database, exclude_session_id: Option<String>, ) -> Result<()>
Delete all sessions for an account
Sourcepub async fn schedule_deletion(&mut self, db: &Database) -> Result<()>
pub async fn schedule_deletion(&mut self, db: &Database) -> Result<()>
Schedule an account for deletion
Sourcepub async fn mark_deleted(&mut self, db: &Database) -> Result<()>
pub async fn mark_deleted(&mut self, db: &Database) -> Result<()>
Removes all information from the account and marks it as fully deleted