Struct revolt_database::Interactions
source · pub struct Interactions {
pub reactions: Option<IndexSet<String>>,
pub restrict_reactions: bool,
}Expand description
Information to guide interactions on this message
Fields
reactions: Option<IndexSet<String>>Reactions which should always appear and be distinct
restrict_reactions: boolWhether reactions should be restricted to the given list
Can only be set to true if reactions list is of at least length 1
Implementations
sourceimpl Interactions
impl Interactions