Struct revolt_database::Message
source · pub struct Message {Show 15 fields
pub id: String,
pub nonce: Option<String>,
pub channel: String,
pub author: String,
pub webhook: Option<MessageWebhook>,
pub content: Option<String>,
pub system: Option<SystemMessage>,
pub attachments: Option<Vec<File>>,
pub edited: Option<Timestamp>,
pub embeds: Option<Vec<Embed>>,
pub mentions: Option<Vec<String>>,
pub replies: Option<Vec<String>>,
pub reactions: IndexMap<String, IndexSet<String>>,
pub interactions: Interactions,
pub masquerade: Option<Masquerade>,
}Expand description
Message
Fields
id: StringUnique Id
nonce: Option<String>Unique value generated by client sending this message
channel: StringId of the channel this message was sent in
Id of the user or webhook that sent this message
webhook: Option<MessageWebhook>The webhook that sent this message
content: Option<String>Message content
system: Option<SystemMessage>System message
attachments: Option<Vec<File>>Array of attachments
edited: Option<Timestamp>Time at which this message was last edited
embeds: Option<Vec<Embed>>Attached embeds to this message
mentions: Option<Vec<String>>Array of user ids mentioned in this message
replies: Option<Vec<String>>Array of message ids this message is replying to
reactions: IndexMap<String, IndexSet<String>>Hashmap of emoji IDs to array of user IDs
interactions: InteractionsInformation about how this message should be interacted with
masquerade: Option<Masquerade>Name and / or avatar overrides for this message
Implementations
sourceimpl Message
impl Message
pub fn apply_options(&mut self, optional_struct: PartialMessage)
sourceimpl Message
impl Message
sourcepub async fn send_without_notifications(
&mut self,
db: &Database,
is_dm: bool,
generate_embeds: bool
) -> Result<()>
pub async fn send_without_notifications( &mut self, db: &Database, is_dm: bool, generate_embeds: bool ) -> Result<()>
Send a message without any notifications