pub trait AbstractAttachmentHashes: Sync + Send {
// Required methods
fn insert_attachment_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
hash: &'life1 FileHash,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn fetch_attachment_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
hash: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<FileHash>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn set_attachment_hash_nonce<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
hash: &'life1 str,
nonce: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn set_attachment_hash_animated<'life0, 'life1, 'async_trait>(
&'life0 self,
hash: &'life1 str,
animated: bool,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn delete_attachment_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Required Methods
Sourcefn insert_attachment_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
hash: &'life1 FileHash,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn insert_attachment_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
hash: &'life1 FileHash,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Insert a new attachment hash into the database.
Sourcefn fetch_attachment_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
hash: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<FileHash>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn fetch_attachment_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
hash: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<FileHash>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Fetch an attachment hash entry by sha256 hash.
Sourcefn set_attachment_hash_nonce<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
hash: &'life1 str,
nonce: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn set_attachment_hash_nonce<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
hash: &'life1 str,
nonce: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Update an attachment hash nonce value.
Sourcefn set_attachment_hash_animated<'life0, 'life1, 'async_trait>(
&'life0 self,
hash: &'life1 str,
animated: bool,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn set_attachment_hash_animated<'life0, 'life1, 'async_trait>(
&'life0 self,
hash: &'life1 str,
animated: bool,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Updates the attachments animated metadata value.
The primary use for this is to update the metadata for existing uploaded files, this can only be used for images.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".