Module util

Module util 

Re-exports

pub use chunked::ChunkedDatabaseGenerator;

Modules

acker
bridge
bulk_permissions
captcha
chunked
email
idempotency
ip
password
permissions
reference
shield
test_fixtures

Functions

format_display_name
Formats a user’s name depending on their optional features and location. Factors in server display names and user display names before falling back to username#discriminator. Passing a server in which the user is not a member will result in an Err.